cmoncrawl.processor.pipeline.pipeline.ProcessorPipeline.process\_domain\_record
===============================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.pipeline

.. automethod:: ProcessorPipeline.process_domain_record